@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2020 Yoran Heling
+  Copyright (c) 2007-2021 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -72,6 +72,7 @@ static struct ctx {
   /* scratch space */
   struct dir    *buf_dir;
   struct dir_ext buf_ext[1];
+  unsigned int nlink;
 
   char buf_name[MAX_VAL];
   char val[MAX_VAL];
@@ -421,7 +422,7 @@ static int itemdir(uint64_t dev) {
 
 
 /* Reads a JSON object representing a struct dir/dir_ext item. Writes to
- * ctx->buf_dir, ctx->buf_ext and ctx->buf_name. */
+ * ctx->buf_dir, ctx->buf_ext, ctx->buf_name and ctx->nlink. */
 static int iteminfo(void) {
   uint64_t iv;
 
@@ -464,12 +465,23 @@ static int iteminfo(void) {
       C(rint64(&iv, UINT64_MAX));
       ctx->buf_dir->flags |= FF_EXT;
       ctx->buf_ext->mtime = iv;
+      // Accept decimal numbers, but discard the fractional part because our data model doesn't support it.
+      if(*ctx->buf == '.') {
+          con(1);
+          while(*ctx->buf >= '0' && *ctx->buf <= '9')
+              con(1);
+      }
     } else if(strcmp(ctx->val, "hlnkc") == 0) {      /* hlnkc */
       if(*ctx->buf == 't') {
         C(rlit("true", 4));
         ctx->buf_dir->flags |= FF_HLNKC;
       } else
         C(rlit("false", 5));
+    } else if(strcmp(ctx->val, "nlink") == 0) {      /* nlink */
+      C(rint64(&iv, UINT32_MAX));
+      if(iv > 1)
+        ctx->buf_dir->flags |= FF_HLNKC;
+      ctx->nlink = iv;
     } else if(strcmp(ctx->val, "read_error") == 0) { /* read_error */
       if(*ctx->buf == 't') {
         C(rlit("true", 4));
@@ -526,6 +538,7 @@ static int item(uint64_t dev) {
 
   memset(ctx->buf_dir, 0, offsetof(struct dir, name));
   memset(ctx->buf_ext, 0, sizeof(struct dir_ext));
+  ctx->nlink = 0;
   *ctx->buf_name = 0;
   ctx->buf_dir->flags |= isdir ? FF_DIR : FF_FILE;
   ctx->buf_dir->dev = dev;
@@ -539,16 +552,16 @@ static int item(uint64_t dev) {
     dir_curpath_enter(ctx->buf_name);
 
   if(isdir) {
-    if(dir_output.item(ctx->buf_dir, ctx->buf_name, ctx->buf_ext)) {
+    if(dir_output.item(ctx->buf_dir, ctx->buf_name, ctx->buf_ext, ctx->nlink)) {
       dir_seterr("Output error: %s", strerror(errno));
       return 1;
     }
     C(itemdir(dev));
-    if(dir_output.item(NULL, 0, NULL)) {
+    if(dir_output.item(NULL, 0, NULL, 0)) {
       dir_seterr("Output error: %s", strerror(errno));
       return 1;
     }
-  } else if(dir_output.item(ctx->buf_dir, ctx->buf_name, ctx->buf_ext)) {
+  } else if(dir_output.item(ctx->buf_dir, ctx->buf_name, ctx->buf_ext, ctx->nlink)) {
     dir_seterr("Output error: %s", strerror(errno));
     return 1;
   }
@@ -561,8 +574,14 @@ static int item(uint64_t dev) {
 
 
 static int footer(void) {
-  C(cons());
-  E(*ctx->buf != ']', "Expected ']'");
+  while(1) {
+    C(cons());
+    if(*ctx->buf == ']')
+      break;
+    E(*ctx->buf != ',', "Expected ',' or ']'");
+    con(1);
+    C(cons() || rval());
+  }
   con(1);
   C(cons());
   E(*ctx->buf, "Trailing garbage");
