@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2020 Yoran Heling
+  Copyright (c) 2007-2021 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -109,8 +109,9 @@ static void item_add(struct dir *item) {
 }
 
 
-static int item(struct dir *dir, const char *name, struct dir_ext *ext) {
+static int item(struct dir *dir, const char *name, struct dir_ext *ext, unsigned int nlink) {
   struct dir *t, *item;
+  (void)nlink;
 
   /* Go back to parent dir */
   if(!dir) {
